==> adonis-ally-azure-ad-0.1.0.tgz: package/README.md <==
<div align="center">
  <img src="https://res.cloudinary.com/adonisjs/image/upload/q_100/v1558612869/adonis-readme_zscycu.jpg" width="600px">
</div>

<br />

<div align="center">
  <h3>AdonisJS Ally x Azure AD</h3>
  <p>
    Azure AD ally driver for AdonisJS ally.
  </p>
</div>

<br />

<div align="center">

[![gh-workflow-image]][gh-workflow-url] [![npm-image]][npm-url] ![][typescript-image] [![license-image]][license-url] [![synk-image]][synk-url]

</div>

<div align="center">
  <h3>
    <!--<a href="https://adonisjs.com">
      Website
    </a>
    <span> | </span>-->
    <a href="https://docs.adonisjs.com/guides/auth/social">
      Guides
    </a>
    <span> | </span>
    <!--<a href="CONTRIBUTING.md">
      Contributing
    </a>
    <span> | </span>-->
    <a href="benchmarks.md">
      Benchmarks
    </a>
  </h3>
</div>

<div align="center">
  <sub>Built with ❤︎ by <a href="https://twitter.com/AlexanderYW">Alexander Wennerstrøm</a>
</div>

[gh-workflow-image]: https://img.shields.io/github/workflow/status/alexanderyw/adonis-ally-azure-ad/test?style=for-the-badge
[gh-workflow-url]: https://github.com/alexanderyw/adonis-ally-azure-ad/actions/workflows/test.yml "Github action"

[typescript-image]: https://img.shields.io/badge/Typescript-294E80.svg?style=for-the-badge&logo=typescript
[typescript-url]:  "typescript"

[npm-image]: https://img.shields.io/npm/v/@alexanderyw/adonis-ally-azure-ad.svg?style=for-the-badge&logo=npm
[npm-url]: https://npmjs.org/package/@alexanderyw/adonis-ally-azure-ad "npm"

[license-image]: https://img.shields.io/npm/l/@alexanderyw/adonis-ally-azure-ad?color=blueviolet&style=for-the-badge
[license-url]: LICENSE.md "license"

[synk-image]: https://img.shields.io/snyk/vulnerabilities/github/alexanderyw/adonis-ally-azure-ad?label=Synk%20Vulnerabilities&style=for-the-badge
[synk-url]: https://snyk.io/test/github/alexanderyw/adonis-ally-azure-ad?targetFile=package.json "synk"

==> adonis-ally-azure-ad-0.1.2.tgz: package/README.md <==
<div align="center">
  <img src="https://res.cloudinary.com/adonisjs/image/upload/q_100/v1558612869/adonis-readme_zscycu.jpg" width="600px">
</div>

<br />

<div align="center">
  <h3>AdonisJS Ally x Azure AD</h3>
  <p>
    Azure AD ally driver for AdonisJS ally.
  </p>
</div>

<br />

<div align="center">

[![gh-workflow-image]][gh-workflow-url] [![npm-image]][npm-url] ![][typescript-image] [![license-image]][license-url] [![synk-image]][synk-url]

</div>

<div align="center">
  <h3>
    <!--<a href="https://adonisjs.com">
      Website
    </a>
    <span> | </span>-->
    <a href="https://docs.adonisjs.com/guides/auth/social">
      Guides
    </a>
    <span> | </span>
    <!--<a href="CONTRIBUTING.md">
      Contributing
    </a>
    <span> | </span>-->
    <a href="benchmarks.md">
      Benchmarks
    </a>
  </h3>
</div>

<div align="center">
  <sub>Built with ❤︎ by <a href="https://twitter.com/AlexanderYW">Alexander Wennerstrøm</a>
</div>
  
[gh-workflow-image]: https://img.shields.io/github/workflow/status/alexanderyw/adonis-ally-azure-ad/Node.js%20CI/main?style=for-the-badge
[gh-workflow-url]: https://github.com/alexanderyw/adonis-ally-azure-ad/.github/workflows/test.yml "Github action"

[typescript-image]: https://img.shields.io/badge/Typescript-294E80.svg?style=for-the-badge&logo=typescript
[typescript-url]:  "typescript"

[npm-image]: https://img.shields.io/npm/v/adonis-ally-azure-ad.svg?style=for-the-badge&logo=npm
[npm-url]: https://npmjs.org/package/adonis-ally-azure-ad "npm"

[license-image]: https://img.shields.io/npm/l/adonis-ally-azure-ad?color=blueviolet&style=for-the-badge
[license-url]: LICENSE.md "license"

[synk-image]: https://img.shields.io/snyk/vulnerabilities/github/alexanderyw/adonis-ally-azure-ad?label=Synk%20Vulnerabilities&style=for-the-badge
[synk-url]: https://snyk.io/test/github/alexanderyw/adonis-ally-azure-ad?targetFile=package.json "synk"
